@@ -9,7 +9,7 @@ use Digest::MD5;
 use Config;
 use CPAN::DistnameInfo;
 use File::Spec;
-use PPM::Make::Config qw(WIN32 HAS_CPAN HAS_PPM HAS_MB ACTIVEPERL);
+use PPM::Make::Config qw(WIN32 HAS_CPAN ACTIVEPERL);
 use HTTP::Tiny;
 
 =head1 NAME
@@ -28,7 +28,7 @@ This module contains a number of utility functions used by PPM::Make.
 
 =cut
 
-our $VERSION = '0.9902';
+our $VERSION = '0.9903';
 
 our (@EXPORT_OK, %EXPORT_TAGS, $protocol, $ext, $src_dir, $build_dir,
      @url_list, $ERROR);
@@ -36,10 +36,10 @@ $protocol = qr{^(http|ftp)://};
 $ext = qr{\.(tar\.gz|tgz|tar\.Z|zip)};
 @url_list = url_list();
 
-my @exports = qw(load_cs verifyMD5 parse_version $ERROR
+my @exports = qw(load_cs verifyMD5 verifySHA256 parse_version $ERROR
                  is_core is_ap_core url_list
-                 trim parse_ppd parse_abstract
-                 ppd2cpan_version cpan2ppd_version tempfile
+                 parse_ppd parse_abstract
+                 ppd2cpan_version cpan2ppd_version
                  file_to_dist cpan_file fix_path
                  mirror
                  $src_dir $build_dir @url_list);
@@ -157,6 +157,9 @@ sub verifyMD5 {
   close $fh;
   if ($should = $cksum->{$file}->{md5}) {
     my $test = ($is eq $should);
+    if (!$test && ($should = $cksum->{$file}->{'md5-ungz'})) {
+      $test = ($is eq $should);
+    }
     printf qq{  Checksum for "$file" is %s\n}, 
       ($test) ? 'OK.' : 'NOT OK.';
     return $test;
@@ -167,6 +170,46 @@ sub verifyMD5 {
   }
 }
 
+=item verifySHA256
+
+Verify a CHECKSUM for a $file
+
+   my $ok = verifySHA256($cksum, $file);
+   print "$file checked out OK" if $ok;
+
+=cut
+
+sub verifySHA256 {
+  my ($cksum, $file) = @_;
+  my ($is, $should);
+  open (my $fh, '<', $file);
+  unless ($fh) {
+    $ERROR = qq{Cannot open "$file": $!};
+    return;
+  }
+  require Digest::SHA;
+  binmode($fh);
+  unless ($is = Digest::SHA->new(256)->addfile($fh)->hexdigest) {
+    $ERROR = qq{Could not compute checksum for "$file": $!};
+    close $fh;
+    return;
+  }
+  close $fh;
+  if ($should = $cksum->{$file}->{sha256}) {
+    my $test = ($is eq $should);
+    if (!$test && ($should = $cksum->{$file}->{'sha256-ungz'})) {
+      $test = ($is eq $should);
+    }
+    printf qq{  SHA256-Checksum for "$file" is %s\n},
+      ($test) ? 'OK.' : 'NOT OK.';
+    return $test;
+  }
+  else {
+    $ERROR = qq{Checksum data for "$file" not present.};
+    return;
+  }
+}
+
 =item is_core
 
 Tests to see if a module is part of the core, based on
@@ -203,23 +246,6 @@ sub is_ap_core {
   return defined $ap_core{$p} ? 1 : 0;
 }
 
-=item trim
-
-Trims white space.
-
-  my $string = '    This is a sentence.   ';
-  my $trimmed = trim($string);
-
-=cut
-
-sub trim {
-  local $_ = shift;
-  s/^\s*//;
-  s/\s*$//;
-  return $_;
-}
-
-
 =item file_to_dist
 
 In scalar context, returns a CPAN distribution name I<filename> based
@@ -515,20 +541,6 @@ sub src_and_build {
   }
 }
 
-=item tempfile
-
-Generates the name of a random temporary file.
-
-  my $tmpfile = tempfile;
-
-=cut
-
-sub tempfile {
-  my $rand = int(rand $$);
-  return File::Spec->catfile(File::Spec->tmpdir(), 
-                             'ppm-make.' . $rand);
-}
-
 =item parse_version
 
 Extracts a version string from a module file.
